@@ -1,7 +1,8 @@
+import re
 import ldap
 from ldap.controls.pagedresults import SimplePagedResultsControl
 
-from .models import UserModel, GroupModel
+from .models import UserModel, GroupModel, SponsorModel
 
 
 class LDAPResult:
@@ -86,6 +87,37 @@ class LDAP:
             page_number=page_number,
         )
 
+    def get_group_sponsors(self, groupname):
+        group_dn = GroupModel.get_sub_dn_for(groupname)
+        filters = f"(&(objectClass=fasGroup)(cn={groupname}))"
+        sponsors_result = self.search(
+            model=SponsorModel,
+            sub_dn=group_dn,
+            attrs=["memberManager"],
+            filters=filters,
+            scope=ldap.SCOPE_SUBTREE,
+        )
+        if not sponsors_result.items:
+            return []
+        return self._sponsors_to_users(sponsors_result)
+
+    def _sponsors_to_users(self, sponsors_dn):
+        sponsors = []
+
+        for sponsor in sponsors_dn.items[0]["sponsors"]:
+            username = re.findall("(?<=uid=)([^,]+)", sponsor)[0]
+            uid = f"uid={username}"
+            sponsors.append(uid)
+
+        filters = ["(&(objectClass=fasUser)(|"]
+        for uid in sponsors:
+            filters.append(f"({uid})")
+        filters.append("))")
+        filters = "".join(filters)
+
+        result = self.search(model=UserModel, filters=filters)
+        return result.items
+
     def get_users(self, page_size, page_number):
         return self.search(
             model=UserModel,
@@ -103,10 +135,57 @@ class LDAP:
             return None
         return result.items[0]
 
+    def get_user_groups(self, username, page_size, page_number):
+        dn = UserModel.get_sub_dn_for(username)
+        filters = f"(&(member={dn},{self.basedn}){GroupModel.filters})"
+        return self.search(
+            model=GroupModel,
+            filters=filters,
+            page_number=page_number,
+            page_size=page_size,
+        )
+
+    def search_users(
+        self,
+        page_number,
+        page_size,
+        username,
+        email,
+        ircnick,
+        givenname,
+        surname,
+    ):
+        filter_fields = {
+            "uid": username,
+            "mail": email,
+            "fasIRCNick": ircnick,
+            "givenName": givenname,
+            "sn": surname,
+        }
+
+        filter_string = ["(&", UserModel.filters, "(&"]
+        for attribute, filter in filter_fields.items():
+            if filter:
+                filter_value = ldap.filter.escape_filter_chars(filter, 0)
+                if attribute == "mail":
+                    filter_string.append(f"({attribute}={filter_value})")
+                else:
+                    filter_string.append(f"({attribute}=*{filter_value}*)")
+        filter_string.append("))")
+        filter_string = "".join(filter_string)
+
+        return self.search(
+            model=UserModel,
+            filters=filter_string,
+            page_size=page_size,
+            page_number=page_number,
+        )
+
     def search(
         self,
         model,
         sub_dn=None,
+        base_dn=None,
         filters=None,
         attrs=None,
         scope=ldap.SCOPE_SUBTREE,
@@ -163,6 +242,13 @@ class LDAP:
                 item[model.primary_key][0].decode("utf-8")
                 for item in pkeys[first:last]
             ]
+            if not pkeys_page:
+                return LDAPResult(
+                    items=[],
+                    page_size=page_size,
+                    page_number=page_number,
+                    total=total,
+                )
             # Now adjust the filters to only get items on this page
             entries_filters = [
                 f"({model.primary_key}={item})" for item in pkeys_page
