@@ -43,6 +43,7 @@ class UserModel(Model):
         "username": Converter("uid"),
         "surname": Converter("sn"),
         "givenname": Converter("givenName"),
+        "human_name": Converter("displayName"),
         "emails": Converter("mail", multivalued=True),
         "ircnicks": Converter("fasIRCNick", multivalued=True),
         "locale": Converter("fasLocale"),
@@ -54,8 +55,17 @@ class UserModel(Model):
     }
 
 
+class SponsorModel(Model):
+    primary_key = "memberManager"
+    filters = "(&(objectClass=fasUser)(!(nsAccountLock=TRUE)))"
+    sub_dn = "cn=users,cn=accounts"
+    fields = {
+        "sponsors": Converter("memberManager", multivalued=True),
+    }
+
+
 class GroupModel(Model):
     primary_key = "cn"
     filters = "(objectClass=fasGroup)"
     sub_dn = "cn=groups,cn=accounts"
-    fields = {"name": Converter("cn")}
+    fields = {"groupname": Converter("cn")}
